@@ -89,7 +89,7 @@ async def handle_tasks(message, mode):
     except IndexError:
         return
     except MessageIdInvalid:
-        await msg.edit('Download Cancelled!')
+        await message.reply_text('Download Cancelled!')
     except FileNotFoundError:
         LOGGER.error('[FileNotFoundError]: Maybe due to cancel, hmm')
     except Exception as e:
@@ -100,7 +100,7 @@ async def handle_tasks(message, mode):
 
 async def tg_task(message, msg):
     filepath = await handle_tg_down(message, msg)
-    await msg.edit('Encoding...')
+    await message.reply_text('Encoding...')
     await handle_encode(filepath, message, msg)
 
 
